wagtail_feedback
================

...

Quick start
-----------

1. Add `wagtail_feedback` and `django_filters` to your INSTALLED_APPS setting like this:

   ```
   INSTALLED_APPS = [
   ...,
   'feedback',
   'django_filters',
   ]
   ```
2. ...
